==> qtjambi-debuginfo-linux-x64-5.15.17.jar: sources/QtJambiGui/QTextBlockGroup_shell.h <==
#ifndef QTEXTBLOCKGROUP_SHELL_H
#define QTEXTBLOCKGROUP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtGui/qtextobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qregexp.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtJambi/RegistryAPI>


class QTextBlockGroup_shell : public QTextBlockGroup, public QtJambiShellInterface
{
public:
    QTextBlockGroup_shell(QTextDocument* doc0);
    ~QTextBlockGroup_shell() override;

    void blockFormatChanged(const QTextBlock& block0) override;
    void blockInserted(const QTextBlock& block0) override;
    void blockRemoved(const QTextBlock& block0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextBlockGroup_access : public QTextBlockGroup
{
    jobject __qt_blockList(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_blockFormatChanged_cref_QTextBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0);
    void __qt_blockInserted_cref_QTextBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0);
    void __qt_blockRemoved_cref_QTextBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0);
};

#endif // QTEXTBLOCKGROUP_SHELL_H

==> qtjambi-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiGui/QTextBlockGroup_shell.h <==
#ifndef QTEXTBLOCKGROUP_SHELL_H
#define QTEXTBLOCKGROUP_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtGui/qtextobject.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtGui/qtextdocument.h>
#include <QtGui/qtextformat.h>
#include <QtJambi/RegistryAPI>


class QTextBlockGroup_shell : public QTextBlockGroup, public QtJambiShellInterface
{
public:
    QTextBlockGroup_shell(QTextDocument* doc0);
    ~QTextBlockGroup_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QTextBlockGroup_mshell;
    friend class QTextBlockGroup_oshell;
};


class QTextBlockGroup_mshell : public QTextBlockGroup_shell
{
public:
    using QTextBlockGroup_shell::QTextBlockGroup_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QTextBlockGroup_oshell : public QTextBlockGroup_mshell
{
public:
    using QTextBlockGroup_mshell::QTextBlockGroup_mshell;
    void blockFormatChanged(const QTextBlock& block0) override;
    void blockInserted(const QTextBlock& block0) override;
    void blockRemoved(const QTextBlock& block0) override;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QTextBlockGroup_access : public QTextBlockGroup
{
    jobject __qt_blockList_constfct(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId) const;
    void __qt_blockFormatChanged_cref_QTextBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0);
    void __qt_blockInserted_cref_QTextBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0);
    void __qt_blockRemoved_cref_QTextBlock(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID block0);
};

#endif // QTEXTBLOCKGROUP_SHELL_H
